"""
Default configuration files for SIRF Config package.

This module contains the default scanner, radionuclide, and protocol
configurations shipped with the package.
"""

# This file makes the default_configs directory a Python package
# The YAML files are included as package data via MANIFEST.in